@@ -15,7 +15,7 @@ class MiddlewareRequest:
 
 @dataclass
 class Middlewares:
-    post_routing: List[Callable[[Dict[str, Any]], None]] = field(
+    post_routing: List[Callable[[str, Dict[str, Any]], None]] = field(
         default_factory=list
     )
     pre_execution: List[Callable[[MiddlewareRequest], None]] = field(
@@ -106,3 +106,6 @@ class CorsMiddleware:
 
         elif isinstance(response.headers, tuple):
             response.headers = response.headers + self.headers_tuple
+
+        elif response.headers is None:
+            response.headers = self.headers_tuple
